@@ -1,5 +1,5 @@
 #![cfg_attr(feature = "nightly",
-    feature(doc_cfg, external_doc, trivial_bounds)
+    feature(doc_cfg, trivial_bounds)
 )]
 #![cfg_attr(not(feature = "std"),
     no_std,
@@ -18,7 +18,7 @@
 )]
 
 #![cfg_attr(feature = "nightly",
-    doc(include = "../README.md")
+    cfg_attr(all(), doc = include_str!("../README.md")),
 )]
 #![cfg_attr(not(feature = "nightly"),
     doc = "See the [user guide](https://getditto.github.io/safer_ffi)."
@@ -38,18 +38,18 @@ extern crate paste;
 mod __utils__;
 use __utils__ as utils;
 
-extern crate proc_macro;
-pub use ::proc_macro::{ffi_export, cfg_headers};
+extern crate safer_ffi_proc_macro;
+pub use ::safer_ffi_proc_macro::{ffi_export, cfg_headers};
 cfg_proc_macros! {
     #[::proc_macro_hack::proc_macro_hack]
     /// Creates a compile-time checked [`char_p::Ref`]`<'static>` out of a
     /// string literal.
     ///
     /// [`char_p::Ref`]: `crate::prelude::char_p::Ref`
-    pub use ::proc_macro::c_str as c;
+    pub use ::safer_ffi_proc_macro::c_str as c;
 
     #[doc(inline)]
-    pub use ::proc_macro::derive_ReprC;
+    pub use ::safer_ffi_proc_macro::derive_ReprC;
 }
 
 #[macro_use]
@@ -98,10 +98,8 @@ mod char_p;
 pub
 mod closure;
 
-const _: () = {
-    #[path = "ffi_export.rs"]
-    mod ffi_export;
-};
+#[path = "ffi_export.rs"]
+mod __ffi_export;
 
 pub
 mod ptr;
