@@ -13,7 +13,7 @@ mod macros;
 pub use crate::{from_CType_impl_ReprC, ReprC, CType};
 
 cfg_proc_macros! {
-    pub use ::proc_macro::{
+    pub use ::safer_ffi_proc_macro::{
         derive_ReprC,
     };
 }
